#
# spec file for package ivykis
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname   libivykis0
Name:           ivykis
Version:        0.43
Release:        1.2
Summary:        An event dispatching library
License:        LGPL-2.1-only
Group:          Development/Libraries/C and C++
URL:            https://sourceforge.net/projects/libivykis/
Source:         https://downloads.sf.net/libivykis/%name-%version.tar.gz
BuildRequires:  c_compiler
BuildRequires:  pkg-config

%description
libivykis is a wrapper over various OS'es implementation of I/O
readiness notification facilities (such as poll(2), kqueue(2)) and
can be used for writing portable network servers.

%package -n %lname
Summary:        An event dispatching library
Group:          System/Libraries

%description -n %lname
libivykis is a wrapper over various OS'es implementation of I/O
readiness notification facilities (such as poll(2), kqueue(2)) and
can be used for writing portable network servers.

%package devel
Summary:        Development files for libivykis, an event dispatching library
Group:          Development/Libraries/C and C++
Requires:       %lname = %version

%description devel
libivykis is a wrapper over various OS'es implementation of I/O
readiness notification facilities (such as poll(2), kqueue(2)) and
can be used for writing portable network servers.

This package contains the header files and development symlinks.

%prep
%autosetup -p1

%build
# includedir intentional, cf. bugzilla.opensuse.org/795968
%configure --disable-static --includedir="%_includedir/%name"
%make_build

%install
%make_install
find %buildroot -type f -name "*.la" -delete -print

%check
%make_build check

%post -n %lname -p /sbin/ldconfig
%postun -n %lname -p /sbin/ldconfig

%files -n %lname
%_libdir/libivykis.so.0*

%files devel
%_includedir/%name/
%_libdir/libivykis.so
%_libdir/pkgconfig/ivykis.pc
%_mandir/man3/iv*.3*
%_mandir/man3/IV*.3*

%changelog
* Thu Feb  8 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.43
  * Added function ``iv_work_pool_submit_continuation``
* Tue May 11 2021 Dirk Müller <dmueller@suse.com>
- update to 0.42.4:
  * iv_event: Fix crash in __iv_event_run_pending_events().
  * Don't install IV_FD_PUMP_INIT.3 when on a case sensitive filesystem.
  * iv_timer: Protect against some cases of timer memory corruption.
  * Avoid marking pthread_atfork() as weak if provided by libc_nonshared.a.
* Fri Sep  8 2017 jengelh@inai.de
- Update to new upstream release 0.42.1
  * Fixes a timer handling bug in the epoll/port poll methods
    that was showing up with syslog-ng.
  * Fixes a timer fairness handling bug, and a potential crash
    when initializing a task handler.
* Tue Feb 21 2017 jengelh@inai.de
- Update to new upstream release 0.41
  * No changelog was provided
- Reenable PPC/ARM builds, the pthread_nonshared edits of 0.40
  should have fixed the issues there.
* Sun Oct 30 2016 jengelh@inai.de
- Update to new upstream release 0.40
  * This release fixes a pthread_sigmask() pointer aliasing issue,
  and significantly speeds up polling for events by using
  timerfd_create(3) / EVFILT_TIMER / timer_create(3C) to avoid
  creating and destroying a kernel timer for every fd readiness
  polling system call.
* Fri Mar 22 2013 jengelh@inai.de
- Downgrade to 0.38+git16 to work around failure on PPC
* Sat Feb 16 2013 jengelh@inai.de
- Update to new upstream release 0.39
  * This release increases the maximum rate of delivery of
  inter-thread events when using the epoll poll method by about 40%%.
* Wed Jan 16 2013 jengelh@inai.de
- Update to new upstream release 0.38
  * This release fixes various bugs, speeds up timer handling a lot
  on a number of BSD platforms, and adds several tests to the test
  suite.
* Thu Dec 20 2012 jengelh@inai.de
- Update to new upstream release 0.37
  * fixes falling back to eventfd(2) if eventfd2(2) was available at
  build time but is not supported by the running kernel
  * adds support for ppoll(2)
* Tue Dec  4 2012 jengelh@inai.de
- Update to new upstream release 0.36
  * Work around a kernel change in FreeBSD 9.0-STABLE where /dev/klog
  has become pollable via kevent(), but returns -EINVAL if you try
  to register an EVFILT_WRITE filter, which confused the
  iv_fd_register_try() logic in iv_fd_kqueue.
  * Rework iv_timer to use less memory when only a small number of
  timers is in use, and allow adding radix tree levels as needed
  to remove the previous ~1M timer limit.
- Update to new upstream release 0.35
  * Fix an abort on iv_work worker thread timeout introduced by the
  race condition fix optimization that went into 0.32.
  * Two iv_event race condition fixes.
* Sat Sep 15 2012 jengelh@inai.de
- Update to new upstream release 0.34
  * This release enables ELF symbol versioning, and adds various
  optimizations and bugfixes.
* Fri Aug 31 2012 jengelh@inai.de
- Initial package (version 0.33) for build.opensuse.org
